==> haskell-bytestring-tree-builder-0.2.7.10-88-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-tree-builder
version:              0.2.7.10
visibility:           public
id:                   bytestring-tree-builder-0.2.7.10-LnUpf0MWnzmDGimtXutAXo
key:                  bytestring-tree-builder-0.2.7.10-LnUpf0MWnzmDGimtXutAXo
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  ba00faf8a8531479c49311bcb6ccf2cf
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Prelude ByteString.TreeBuilder.Poker
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/bytestring-tree-builder-0.2.7.10

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/bytestring-tree-builder-0.2.7.10

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.10-LnUpf0MWnzmDGimtXutAXo
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.10-97-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-tree-builder
version:              0.2.7.10
visibility:           public
id:                   bytestring-tree-builder-0.2.7.10-KFckFj1AcKz3g1LUmsLz3M
key:                  bytestring-tree-builder-0.2.7.10-KFckFj1AcKz3g1LUmsLz3M
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  aa0646beeff185ad9a78ea7a87147d03
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Prelude ByteString.TreeBuilder.Poker
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/bytestring-tree-builder-0.2.7.10

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/bytestring-tree-builder-0.2.7.10

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.10-KFckFj1AcKz3g1LUmsLz3M
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
